@@ -20,10 +20,10 @@ module Cucumber
             @expression_regexp,
             text
           ) || ParameterType.new(
-            parameter_type_regexp,
+            nil,
             parameter_type_regexp,
             String,
-            lambda {|s| s},
+            lambda {|*s| s[0]},
             false,
             false
           )
