@@ -34,7 +34,7 @@ module Cucumber
         it "translates parameters" do
           assert_regexp(
             "I have {float} cukes at {int} o'clock",
-            /^I have (-?\d*\.\d+) cukes at ((?:-?\d+)|(?:\d+)) o'clock$/
+            /^I have ((?=.*\d.*)[-+]?\d*(?:\.(?=\d.*))?\d*(?:\d+[E][-+]?\d+)?) cukes at ((?:-?\d+)|(?:\d+)) o'clock$/
           )
         end
 
@@ -44,6 +44,13 @@ module Cucumber
             /^I have many big(?:ish)? cukes$/
           )
         end
+
+        it "translates parenthesis with alpha unicode" do
+          assert_regexp(
+            "Привет, Мир(ы)!",
+            /^Привет, Мир(?:ы)?!$/
+          )
+        end
       end
     end
   end
